@@ -104,8 +104,8 @@ class GaussianMixtureBase(metaclass=ABCMeta):
 
     version : 0.1
     """
-    def __init__(self, n_components, cov_type, tol, max_iter,
-                 n_init):
+    def __init__(self, n_components: int, cov_type: str, tol: float, max_iter: int,
+                 n_init: int):
         self.n_components = n_components
         self.cov_type = cov_type
         self.tol = tol
@@ -157,7 +157,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
 
     @abstractmethod
     def _calc_secondary_centers_unc(self, c1s, c1s_err, c2s,
-                                    c2s_err, data_frame_object):
+                                    c2s_err, data_frame_object: object):
         """Calculate the coordinates of the cluster centers for the coordinate system
         that was not used for the fit.
 
@@ -190,7 +190,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def _calculate_centers_uncertainties(self, data_frame_object):
+    def _calculate_centers_uncertainties(self, data_frame_object: object):
         """After clustering the data, organize the cluster centers into a more accessible format.
 
         Assigns the attributes 'centers_array_', 'ips_',
@@ -206,7 +206,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def recalculate_centers_uncertainties(self, data_frame_object):
+    def recalculate_centers_uncertainties(self, data_frame_object: object):
         """Recalculate the centers of each cluster and the uncertainties in the centers.
 
         This uses a different method from simply extracting the centers
@@ -241,7 +241,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def cluster_data(self, data_frame_object):
+    def cluster_data(self, data_frame_object: object):
         """Use the Gaussian Mixture fits from the sklearn package to cluster the data.
 
         Assigns the object the attributes 'means_',
@@ -258,7 +258,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def cluster_data_strict(self, data_frame_object):
+    def cluster_data_strict(self, data_frame_object: object):
         """Cluster the data, but restrict n_components to the value of the parameter 'n_components'.
 
         Assigns the mixture object the attributes 'means_',
@@ -308,8 +308,8 @@ class GaussianMixtureBase(metaclass=ABCMeta):
                 self.noise_colors_.append(colors[self.unique_labels_[i]])
 
     @abstractmethod
-    def fit_over_one_dimensional_histograms(self, fig, axs,
-                                            data_frame_object):
+    def fit_over_one_dimensional_histograms(self, fig: object, axs,
+                                            data_frame_object: object):
         """Fit over the histograms generated with the data frame object.
 
         Given a data frame object that has already been used
@@ -339,7 +339,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def get_pdf_fig(self, data_frame_object):
+    def get_pdf_fig(self, data_frame_object: object):
         """Plot the pdf of the Gaussian mixture on a surface.
 
         The returned matplotlib.plyplot figure can be shown and saved
@@ -364,7 +364,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
         pass
 
     @abstractmethod
-    def get_results_fig(self, data_frame_object):
+    def get_results_fig(self, data_frame_object: object):
         """Return the clustering results.
 
         The returned matplotlib.plyplot figure may be shown
@@ -390,7 +390,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
         """
         pass
 
-    def cluster_merger(self, data_frame_object):
+    def cluster_merger(self, data_frame_object: object):
         """Merge clusters into one spot in the case of an over-fitting error.
 
         After showing the initial results of a clustering fit, this
