@@ -136,10 +136,10 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         is one that we can't conclude is composed of identical ion species.
     """
 
-    def __init__(self, n_components=1, *, cov_type='full', tol=1e-5,
-                 max_iter=500, n_init=30, coordinates='Cartesian',
-                 weight_concentration_prior_type='dirichlet_process',
-                 weight_concentration_prior=None):
+    def __init__(self, n_components: int = 1, *, cov_type: str = 'full', tol: float = 1e-5,
+                 max_iter: int = 500, n_init: int = 30, coordinates: str = 'Cartesian',
+                 weight_concentration_prior_type: str = 'dirichlet_process',
+                 weight_concentration_prior: float = None):
         super().__init__(
             n_components=n_components, cov_type=cov_type, tol=tol,
             max_iter=max_iter, n_init=n_init)
@@ -154,6 +154,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         self.weight_concentration_prior = weight_concentration_prior
         self.clustered_ = False
         self.n_comps_found_ = self.n_components
+        self.noise_colors_ = []
 
     def _check_parameters(self):
         """Check the parameters that don't originate in the base model."""
@@ -224,7 +225,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         return model
 
     def _calc_secondary_centers_unc(self, c1s, c1s_err, c2s,
-                                    c2s_err, data_frame_object):
+                                    c2s_err, data_frame_object: object):
         """Calculate the coordinates of the cluster centers for the coordinate system that
         was not used for the fit.
 
@@ -340,7 +341,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         self._identify_noise_colors(data_frame_object=data_frame_object)
 
-    def _calculate_centers_uncertainties(self, data_frame_object):
+    def _calculate_centers_uncertainties(self, data_frame_object: object):
         """After clustering the data, organize the cluster centers into a more accessible format.
 
         Assigns the attributes 'centers_array_', 'ips_',
@@ -406,7 +407,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         for i in self.unique_labels_:
             self.colors_.append(colors[i])
 
-    def recalculate_centers_uncertainties(self, data_frame_object):
+    def recalculate_centers_uncertainties(self, data_frame_object: object):
         """Recalculate the centers of each cluster and the uncertainties in the centers.
 
         This uses a different method from simply extracting the centers
@@ -560,8 +561,8 @@ class BayesianGaussianMixture(GaussianMixtureBase):
             plt.title('BGM %i comps c1_bins (cadetblue) = %i ; c2_bins '
                       '(orange) = %i\n(c1, c2) = (%0.2f,%0.2f),'
                       'Cluster unc=%0.5f' % (
-                        self.n_comps_found_, num_bins(c1_cut),
-                        num_bins(c2_cut), c1s[i], c2s[i], cluster_err[i]))
+                          self.n_comps_found_, num_bins(c1_cut),
+                          num_bins(c2_cut), c1s[i], c2s[i], cluster_err[i]))
             plt.xlim(-10, 10)
             plt.show()
 
@@ -590,7 +591,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         self.responsibilities_ = model.predict_proba(x)
         self.n_comps_found_ = np.shape(self.weights_)[0]
 
-    def cluster_data(self, data_frame_object):
+    def cluster_data(self, data_frame_object: object):
         """Use the Bayesian Gaussian Mixture from the sklearn package to cluster the data.
 
         Assigns the object the attributes 'means_',
@@ -629,7 +630,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         self._calculate_centers_uncertainties(data_frame_object)
 
-    def cluster_data_strict(self, data_frame_object):
+    def cluster_data_strict(self, data_frame_object: object):
         """Cluster the data, but restrict n_components to the value of the parameter 'n_components'.
 
         Assigns the mixture object the attributes 'means_',
@@ -668,8 +669,8 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         self._calculate_centers_uncertainties(data_frame_object)
 
-    def fit_over_one_dimensional_histograms(self, fig, axs,
-                                            data_frame_object):
+    def fit_over_one_dimensional_histograms(self, fig: object, axs,
+                                            data_frame_object: object):
         """Fit over the histograms generated with the data frame object.
 
         Given a data frame object that has already been used
@@ -733,7 +734,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         return fig
 
-    def get_pdf_fig(self, data_frame_object):
+    def get_pdf_fig(self, data_frame_object: object):
         """Plot the pdf of the Bayesian Gaussian mixture on a surface.
 
         The returned matplotlib.plyplot figure can be shown and saved
@@ -848,7 +849,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         return fig, save_string
 
-    def get_results_fig(self, data_frame_object):
+    def get_results_fig(self, data_frame_object: object):
         """Display the clustering results.
 
         The returned matplotlib.plyplot figure may be shown
@@ -911,15 +912,15 @@ class BayesianGaussianMixture(GaussianMixtureBase):
                 r"%s%i counts (%.1f%%), x=%.3f$\pm$ %.3f, "
                 r"y=%.3f$\pm$%.3f, r=%.3f$\pm$%.3f, "
                 r"p=%.3f$\pm$%.3f" % (('*' if self.colors_[i] in self.noise_colors_ else ''),
-                    self.ips_[i], 100.0 * self.ips_[i] / n_samples,
-                    self.centers_array_[i, 0],
-                    self.centers_array_[i, 1],
-                    self.centers_array_[i, 2],
-                    self.centers_array_[i, 3],
-                    self.centers_array_[i, 4],
-                    self.centers_array_[i, 5],
-                    self.centers_array_[i, 6],
-                    self.centers_array_[i, 7]))
+                                      self.ips_[i], 100.0 * self.ips_[i] / n_samples,
+                                      self.centers_array_[i, 0],
+                                      self.centers_array_[i, 1],
+                                      self.centers_array_[i, 2],
+                                      self.centers_array_[i, 3],
+                                      self.centers_array_[i, 4],
+                                      self.centers_array_[i, 5],
+                                      self.centers_array_[i, 6],
+                                      self.centers_array_[i, 7]))
         labels.append(discarded_counts_stuff)
 
         label_indices = np.arange(0, len(self.unique_labels_))
